import path$1 from 'node:path';

// From: https://github.com/sindresorhus/slash/blob/98b618f5a3bfcb5dd374b204868818845b87bb2f/index.js#L1-9
const enforceForwardSlashes = (fileOrFolder) => {
    const isExtendedLengthPath = fileOrFolder.startsWith(`\\\\?\\`); // See https://learn.microsoft.com/en-us/windows/win32/fileio/naming-a-file#win32-file-namespaces:~:text=file%20I/O%2C-,the%20%22%5C%5C%3F%5C%22%20prefix,-to%20a%20path
    if (isExtendedLengthPath) {
        return fileOrFolder;
    }
    return fileOrFolder.replaceAll(`\\`, `/`);
};

const normalize = (fileOrFolder) => {
    return enforceForwardSlashes(path$1.normalize(fileOrFolder));
};
const join = (...pathSegments) => {
    return enforceForwardSlashes(path$1.join(...pathSegments));
};
const resolve = (...pathSegments) => {
    return enforceForwardSlashes(path$1.resolve(...pathSegments));
};
const isAbsolute = (fileOrFolder) => {
    fileOrFolder = enforceForwardSlashes(fileOrFolder);
    return path$1.isAbsolute(fileOrFolder);
};
const relative = (from, to) => {
    return enforceForwardSlashes(path$1.relative(from, to));
};
const dirname = (fileOrFolder) => {
    return enforceForwardSlashes(path$1.dirname(fileOrFolder));
};
const basename = (fileOrFolder, suffix) => {
    return enforceForwardSlashes(path$1.basename(fileOrFolder, suffix));
};
const extname = (fileOrFolder) => {
    return enforceForwardSlashes(path$1.extname(fileOrFolder));
};
const parse = (fileOrFolder) => {
    const data = path$1.parse(fileOrFolder);
    data.root = enforceForwardSlashes(data.root);
    data.dir = enforceForwardSlashes(data.dir);
    data.base = enforceForwardSlashes(data.base);
    data.ext = enforceForwardSlashes(data.ext);
    data.name = enforceForwardSlashes(data.name);
    return data;
};
const format = (fileOrFolderObject) => {
    return enforceForwardSlashes(path$1.format(fileOrFolderObject));
};
const toNamespacedPath = (fileOrFolder) => {
    return enforceForwardSlashes(path$1.toNamespacedPath(fileOrFolder));
};

const hasSlash = (fileOrFolder) => {
    const hasForwardSlash = fileOrFolder.includes(`/`);
    if (hasForwardSlash) {
        return true;
    }
    const hasBackwardSlash = fileOrFolder.includes(`\\`);
    if (hasBackwardSlash) {
        return true;
    }
    return false;
};
const isName = (fileOrFolder) => {
    return !hasSlash(fileOrFolder);
};
const stem = (fileOrFolder) => {
    const fileName = path$1.basename(fileOrFolder);
    const dotIndex = fileName.lastIndexOf(`.`);
    if (dotIndex === -1) {
        return fileName;
    }
    return fileName.slice(0, dotIndex);
};
const extension = (fileOrFolder) => {
    const fileName = path$1.basename(fileOrFolder);
    const dotIndex = fileName.lastIndexOf(`.`);
    if (dotIndex === -1) {
        return;
    }
    return fileName.slice(dotIndex + 1);
};
const indexBeforeExtension = (fileOrFolder) => {
    const dotIndex = fileOrFolder.lastIndexOf(`.`);
    if (dotIndex === -1) {
        return;
    }
    return dotIndex;
};
const withoutExtension$1 = (fileOrFolder) => {
    const inputIndexBeforeExtension = indexBeforeExtension(fileOrFolder);
    if (inputIndexBeforeExtension === undefined) {
        return fileOrFolder;
    }
    return fileOrFolder.slice(0, inputIndexBeforeExtension);
};
const indexAfterParent = (fileOrFolder) => {
    const forwardParentIndex = fileOrFolder.lastIndexOf(`/`);
    if (forwardParentIndex !== -1) {
        return forwardParentIndex + 1;
    }
    const backwardParentIndex = fileOrFolder.lastIndexOf(`\\`);
    if (backwardParentIndex !== -1) {
        return backwardParentIndex + 1;
    }
};
const indexBeforeName = (fileOrFolder) => {
    const forwardParentIndex = fileOrFolder.lastIndexOf(`/`);
    if (forwardParentIndex !== -1) {
        return forwardParentIndex + 1;
    }
    const backwardParentIndex = fileOrFolder.lastIndexOf(`\\`);
    if (backwardParentIndex !== -1) {
        return backwardParentIndex + 1;
    }
    return 0;
};
const isDotFile = (fileOrFolder) => {
    const beforeNameIndex = indexBeforeName(fileOrFolder);
    const firstNameCharacter = fileOrFolder[beforeNameIndex];
    return firstNameCharacter === `.`;
};
const addSuffix$1 = (fileOrFolder, suffix) => {
    const dotIndex = indexBeforeExtension(fileOrFolder);
    if (dotIndex === -1) {
        return fileOrFolder + suffix;
    }
    const fileBase = fileOrFolder.slice(0, dotIndex);
    const fileExtension = fileOrFolder.slice(dotIndex);
    return `${fileBase}${suffix}${fileExtension}`;
};
const addPrefix$1 = (fileOrFolder, prefix) => {
    const beforeNameIndex = indexBeforeName(fileOrFolder);
    if (beforeNameIndex === 0) {
        return `${prefix}${fileOrFolder}`;
    }
    const folderPart = fileOrFolder.slice(0, beforeNameIndex);
    const name = fileOrFolder.slice(beforeNameIndex);
    return `${folderPart}${prefix}${name}`;
};
const replaceExtension$1 = (fileOrFolder, newExtension) => {
    const currentExtension = extension(fileOrFolder);
    if (currentExtension === undefined) {
        return `${fileOrFolder}.${newExtension}`;
    }
    if (currentExtension === newExtension) {
        return;
    }
    const fileBase = fileOrFolder.slice(0, -currentExtension.length);
    return `${fileBase}${newExtension}`;
};
const replaceStem$1 = (fileOrFolder, newStem) => {
    const beforeNameIndex = indexBeforeName(fileOrFolder);
    const beforeExtensionIndex = indexBeforeExtension(fileOrFolder);
    if (beforeNameIndex === 0 && beforeExtensionIndex === undefined) {
        return newStem;
    }
    const folderPart = fileOrFolder.slice(0, beforeNameIndex);
    if (beforeExtensionIndex === undefined) {
        return `${folderPart}${newStem}`;
    }
    const fileExtension = fileOrFolder.slice(beforeExtensionIndex);
    return `${folderPart}${newStem}${fileExtension}`;
};
const parentName = (fileOrFolder) => {
    const beforeNameIndex = indexBeforeName(fileOrFolder);
    if (beforeNameIndex === 0) {
        return;
    }
    const folderPart = fileOrFolder.slice(0, beforeNameIndex - 1);
    return path$1.basename(folderPart);
};

const withoutExtension = (fileOrFolder) => {
    const fileOrFolderNormalized = enforceForwardSlashes(fileOrFolder);
    return withoutExtension$1(fileOrFolderNormalized);
};
const addSuffix = (fileOrFolder, suffix) => {
    const fileOrFolderNormalized = enforceForwardSlashes(fileOrFolder);
    return addSuffix$1(fileOrFolderNormalized, suffix);
};
const addPrefix = (fileOrFolder, prefix) => {
    const fileOrFolderNormalized = enforceForwardSlashes(fileOrFolder);
    return addPrefix$1(fileOrFolderNormalized, prefix);
};
const replaceExtension = (fileOrFolder, newExtension) => {
    const fileOrFolderNormalized = enforceForwardSlashes(fileOrFolder);
    return replaceExtension$1(fileOrFolderNormalized, newExtension);
};
const replaceStem = (fileOrFolder, newStem) => {
    const fileOrFolderNormalized = enforceForwardSlashes(fileOrFolder);
    return replaceStem$1(fileOrFolderNormalized, newStem);
};

const lib = /*#__PURE__*/Object.freeze({
    __proto__: null,
    addPrefix,
    addSuffix,
    basename,
    dirname,
    extension,
    extname,
    format,
    hasSlash,
    indexAfterParent,
    indexBeforeExtension,
    indexBeforeName,
    isAbsolute,
    isDotFile,
    isName,
    join,
    normalize,
    parentName,
    parse,
    relative,
    replaceExtension,
    replaceStem,
    resolve,
    stem,
    toNamespacedPath,
    withoutExtension
});

const path = Object.assign(enforceForwardSlashes, lib);

export { addPrefix, addSuffix, basename, path as default, dirname, enforceForwardSlashes, extension, extname, format, hasSlash, indexAfterParent, indexBeforeExtension, indexBeforeName, isAbsolute, isDotFile, isName, join, normalize, parentName, parse, path, relative, replaceExtension, replaceStem, resolve, stem, toNamespacedPath, withoutExtension };
